--- title: "wallaroo.pipeline_version" type: docs linkTitle: "wallaroo.pipeline_version" ---
class PipelineVersion(wallaroo.object.Object):

Base class for all backend GraphQL API objects.

This class serves as a framework for API objects to be constructed based on a partially-complete JSON response, and to fill in their remaining members dynamically if needed.

PipelineVersion(client: Optional[wallaroo.client.Client], data: Dict[str, Any])

Base constructor.

Each object requires:

- a GraphQL client - in order to fill its missing members dynamically
- an initial data blob - typically from unserialized JSON, contains at
- least the data for required members (typically the object's primary key) and optionally other data members.

def id(self) -> int:
def create_time(*args, **kwargs):
def last_update_time(*args, **kwargs):
def name(*args, **kwargs):
def definition(*args, **kwargs):
def pipeline(*args, **kwargs):
def deployments(*args, **kwargs):
def model_configs(*args, **kwargs):
def deploy( self, deployment_name: str, model_configs: List[wallaroo.model_config.ModelConfig], config: Optional[wallaroo.deployment_config.DeploymentConfig] = None) -> wallaroo.deployment.Deployment:

Deploys this PipelineVersion.

###### Parameters

- str deployment_name: Name of the new Deployment. Must be unique across all deployments.
- List[ModelConfig] model_configs: List of the configured models to use. These must be the same ModelConfigs used when creating the Pipeline.
- Optional[DeploymentConfig] config: Deployment configuration to use.

###### Returns

> A Deployment object for the resulting deployment.

class PipelineVersionList(typing.List[wallaroo.pipeline_version.PipelineVersion]):

Wraps a list of pipelines for display in a display-aware environment like Jupyter.

##### Inherited Members

builtins.list
  list
  clear
  copy
  append
  insert
  extend
  pop
  remove
  index
  count
  reverse
  sort